@@ -15,6 +15,7 @@
 """nRF52840 platform device class."""
 from gazoo_device import detect_criteria
 from gazoo_device.base_classes import nrf_connect_sdk_device
+from gazoo_device.utility import pwrpc_utils
 
 
 class NRF52840(nrf_connect_sdk_device.NRFConnectSDKDevice):
@@ -27,7 +28,8 @@ class NRF52840(nrf_connect_sdk_device.NRFConnectSDKDevice):
   DETECT_MATCH_CRITERIA = {
       detect_criteria.PigweedQuery.product_name: "j-link",
       detect_criteria.PigweedQuery.manufacturer_name: "segger",
-      detect_criteria.PigweedQuery.app_type: "nonpigweed",
+      detect_criteria.PigweedQuery.app_type:
+          pwrpc_utils.PigweedAppType.NON_PIGWEED.value,
   }
   DEVICE_TYPE = "nrf52840"
   _OWNER_EMAIL = "gdm-authors@google.com"
